pyramid_localize
================

.. image:: https://pypip.in/v/pyramid_localize/badge.png
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pyramid_localize/badge.png
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: Number of PyPI downloads

.. image:: https://pypip.in/wheel/pyramid_localize/badge.png
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: Wheel Status

.. image:: https://pypip.in/egg/pyramid_localize/badge.png
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: Egg Status

.. image:: https://pypip.in/license/pyramid_localize/badge.png
    :target: https://pypi.python.org/pypi/pyramid_localize/
    :alt: License

Package provides translation methods for pyramid, and means to reload translations
without stopping the application.


Package status
--------------

.. image:: https://travis-ci.org/fizyk/pyramid_localize.png?branch=master
    :target: https://travis-ci.org/fizyk/pyramid_localize
    :alt: Tests

.. image:: https://coveralls.io/repos/fizyk/pyramid_localize/badge.png?branch=master
    :target: https://coveralls.io/r/fizyk/pyramid_localize?branch=master
    :alt: Coverage Status

.. image:: https://requires.io/github/fizyk/pyramid_localize/requirements.png?branch=master
   :target: https://requires.io/github/fizyk/pyramid_localize/requirements/?branch=master
   :alt: Requirements Status



Package resources
-----------------

* Bug tracker: https://github.com/fizyk/pyramid_localize/issues
* Documentation: http://pyramid-localize.readthedocs.org/
* PyPI: https://pypi.python.org/pypi/pyramid_localize


Instalation:
============

``pip install pyramid_localize``

or add **pyramid_localize** to your **setup.py** requirements.


Tests:
======

You'll need: packages defined in extra_requires[tests] to run tests, and then:

``python setup.py nosetests``
